---

license: Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements. See the NOTICE file distributed with this work for additional information regarding copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

           http://www.apache.org/licenses/LICENSE-2.0
    
         Unless required by applicable law or agreed to in writing,
         software distributed under the License is distributed on an
         "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
         KIND, either express or implied.  See the License for the
         specific language governing permissions and limitations
         under the License.
    

---

# Интерфейс командной строки

Это руководство показывает, как создавать приложения и развернуть их в различных родной мобильных платформ с использованием `cordova` интерфейс командной строки (CLI). Эта программа позволяет вам создавать новые проекты, собирать их на различных платформах, и запускать ваше приложение на устройствах или в эмуляторах. CLI это основной инструмент для кросс-платформенной процесса разработки (Смотрите "Обзор" для описания различных процессов разработки.) Однако, вы также можете использовать CLI для инициализации кода проекта, после чего вы можете использовать SDK различных платформ и инструменты командной строки для дальнейшей разработки.

## Необходимые условия

Перед запуском любого средства командной строки, необходимо установить пакет SDK для каждой платформы, которую вы хотите цели. (См. платформа руководства для получения более подробной информации.)

Чтобы добавить поддержку или перестроить проект для любой платформы, вы должны запустить интерфейс командной строки из той же машине, который поддерживает платформы SDK. CLI поддерживает следующие комбинации:

*   iOS (Mac)
*   Amazon Fire OS (Mac, Linux, Windows)
*   Android (Mac, Linux)
*   BlackBerry 10 (Mac, Linux, Windows)
*   Windows Phone 7 (Windows)
*   Windows Phone 8 (Windows)
*   Windows 8 (Windows)
*   Firefox OS (Mac, Linux, Windows)

На Mac командная строка доступна с помощью приложения *Терминал*. На ПК он доступен как приложение *Командная строка* в разделе *Аксессуары*.

Скорее всего, вы будете запускать CLI с различных компьютеров, тем больше имеет смысл поддерживать удаленный репозиторий, откуда вы будете забирать рабочие материалы в локальные каталоги.

Чтобы установить инструмент командной строки `cordova`, выполните следующие действия:

1.  Скачайте и установите [Node.js][1]. После установки, вы должны иметь возможность вызвать `node` или `npm` в вашей командной строке.

2.  Установить утилиту `cordova`. В Unix, возможно будет необходимо предварить команды установки дополнительной командой `sudo`, для установки утилиты разработки в закрытые в противном случае каталоги:
    
        $ sudo npm install -g cordova
        
    
    Журнал установки может отображать ошибки для любого удаленного SDK платформы. После установки, вы должны иметь возможность запускать `cordova` в командной строке.
    
    **ПРИМЕЧАНИЕ**: Флаг `-g` указывает npm установить cordova глобально. Возможно вам понадобиться добавить каталог npm в переменную PATH для того чтобы вызывать глобально установленные модули npm. На Windows, npm обычно может быть найдена в каталоге `C:\Users\username\AppData\Roaming\npm` и в Unix в каталоге `/usr/local/share/npm`.

 [1]: http://nodejs.org/

## Создание приложения

Перейдите в каталог, где вы сохранили ваш исходный код и выполнить команду следующего вида:

        $ cordova create hello com.example.hello HelloWorld
    

Завершение команды может длиться дольше нескольких секунд, поэтому будьте терпеливы. Запуск команды с опцией `-d` будет показывать информацию о прогрессе операции.

Первый аргемент - *hello* указывает каталог в котором будет сформирован ваш проект. Этот каталог не должен существовать, Cordova создаст его для вас. Подкаталог `www` созданной директории будет содержать домашнюю страницу вашего приложения, совместно с ресурсами в каталогах `css`, `js`, и `img`, что соответствует общепринятым соглашениям по наименованию файлов и каталогов принятых в веб-разработке. Файл `config.xml` содержит важные метаданные необходимые для формирования и распространения приложения.

Второй аргумент `com.example.hello` указывает идентификатор вашего проекта в обратном формате доменных имен. Этот аргумент является обязательным, но только если вы также опущен третий аргумент, поскольку позиционные аргументы. Можно изменить это значение позднее в `config.xml` файла, но следует учитывать, что, возможно, код, созданный вне `config.xml` с помощью этого значения, например имена пакетов Java. Значением по умолчанию является `io.cordova.hellocordova` , но это рекомендуется, что вы выберите соответствующее значение.

Третий аргумент `HelloWorld` содержит название приложения отображения. Этот аргумент является необязательным. Можно изменить это значение позднее в `config.xml` файла, но следует учитывать, что, возможно, код, созданный вне `config.xml` с помощью этого значения, такие как имена классов Java. Значением по умолчанию является `HelloCordova` , но это рекомендуется, что вы выберите соответствующее значение.

## Добавить платформы

Все последующие команды должны быть запущены в каталог проекта или подкаталоги в пределах своей области:

        $ cd hello
    

Перед тем, как можно построить проект, необходимо указать набор целевых платформ. Ваши способности для запуска этих команд зависит от того, поддерживает ли ваша машина каждого пакета SDK, и есть ли у вас уже установлен каждого пакета SDK. Запустите любой из них от Mac:

        $ cordova platform add ios
        $ cordova platform add amazon-fireos
        $ cordova platform add android
        $ cordova platform add blackberry10
        $ cordova platform add firefoxos
    

Запустите любой из них из окна машины, где *wp* относится к различных версий операционной системы Windows Phone:

        $ cordova platform add wp7
        $ cordova platform add wp8
        $ cordova platform add windows8
        $ cordova platform add amazon-fireos
        $ cordova platform add android
        $ cordova platform add blackberry10
        $ cordova platform add firefoxos
    

Выполните это, чтобы проверить ваш текущий набор платформ:

        $ cordova platforms ls
    

(Примечание `platform` и `platforms` команды являются синонимами.)

Выполните одну из следующих команд синонимом чтобы удалить платформу:

        $ cordova platform remove blackberry10
        $ cordova platform rm amazon-fireos
        $ cordova platform rm android
    

Выполнение команд для добавления или удаления платформ влияет содержимое каталога *платформы* проекта, где каждый указанной платформе появляется как подкаталог. Исходный каталог *www* воспроизводится в подкаталоге каждой платформы, например появление в `platforms/ios/www` или `platforms/android/assets/www` . Потому что CLI постоянно копирует файлы из исходной папки *www* , следует только изменять эти файлы, а не те, расположенные в подкаталогах *платформ* . При использовании управления версиями программного обеспечения, следует добавить этот источник папку *www* , наряду с папке *сливается* для системы управления версиями. (Дополнительные сведения о папке *сливается* можно найти в разделе Настройка каждой платформы ниже.)

**Предупреждение**: при использовании командной строки для построения приложения, вам настоятельно не рекомендуется изменять любые файлы в `/platforms/` папке если вы не знаете, что вы делаете, или специально сказал в противном случае в документации. Это потому, что файлы в `/platforms/` каталоге будут перезаписаны на готовить или переустановки плагина.

Если вы хотите на данный момент, можно использовать пакет SDK, например Eclipse или Xcode чтобы открыть проект, созданный вами. Вам нужно будет открыть набор производных активов из `/platforms/` каталог для разработки с пакетом SDK. Это потому, что файлы SDK конкретных метаданных хранятся в соответствующей `/platform/` подкаталога. (См. руководства платформы для получения информации о том, как разрабатывать приложения в каждой интегрированной среде разработки.) Этот подход следует используйте, если вы просто хотите, чтобы инициализировать проект, с помощью командной строки и затем переключиться на SDK для родной работы.

Читайте дальше, если вы хотите использовать кросс платформенный рабочего подхода (CLI) для весь цикл разработки.

## Построение приложения

По умолчанию `cordova create` скрипт генерирует скелетных веб-приложение, чья Главная страница — проект `www/index.html` файл. Изменить это приложение, вы хотите, но любой инициализации должен быть указан как часть `deviceready` обработчика событий, ссылки по умолчанию`www/js/index.js`.

Выполните следующую команду для последовательного построения проекта:

        $ cordova build
    

Это создает код платформы в рамках проекта `platforms` подкаталога. При необходимости можно ограничить сферу применения каждой сборки для конкретных платформ:

        $ cordova build ios
    

`cordova build`Команда это сокращение для следующее, что в этом примере также ориентирована на единой платформе:

        $ cordova prepare ios
        $ cordova compile ios
    

В этом случае, после запуска `prepare` , Xcode SDK от Apple можно использовать в качестве альтернативы изменить и скомпилировать платформенно зависимый код, генерирующий Кордова в `platforms/ios` . Можно использовать тот же подход с другой платформы SDK.

## Тестирование приложения на эмуляторе или устройстве

SDK для мобильных платформ, которые часто поставляются в комплекте с эмуляторов, которые выполняются изображения устройства, так что вы можете запустить приложение на главном экране и посмотреть, как он взаимодействует с многими функциями платформы. Выполните команду, например восстановить приложение и просмотреть его в пределах определенной платформы эмулятора:

        $ cordova emulate android
    

Некоторые мобильные платформы эмулировать конкретного устройства по умолчанию, такие как iPhone на iOS проектов. Для других платформ необходимо сначала связать устройство с эмулятором.

Примечание: Эмулятор поддержка недоступна в настоящее время Amazon Fire ОС

(См. руководства платформы для подробной информации). Например, вы можете сначала запустить `android` команду для запуска Android SDK, а затем запустить образ конкретного устройства, который запускает его согласно его поведение по умолчанию:

![][2]

 [2]: img/guide/cli/android_emulate_init.png

Следующие вверх с `cordova emulate` команда обновляет образ эмулятора для отображения последние приложения, который теперь доступен для запуска на главном экране:

![][3]

 [3]: img/guide/cli/android_emulate_install.png

Поочередно можно подключить телефон к компьютеру и тестирование приложения непосредственно:

        $ cordova run android
    

Перед выполнением этой команды, необходимо настроить устройство для тестирования, следуя процедурам, которые различаются для каждой платформы. В Android и Amazon Fire ОС устройства вам придется включить **отладку USB** вариант на устройстве и возможно добавить драйвер USB в зависимости от вашего развития далее. Смотрите подробную информацию о потребностях каждой платформы платформы руководства.

## Добавить плагин функции

При построении и посмотреть новый проект приложения по умолчанию, которое появляется не очень много. Вы можете изменить приложение во многих отношениях, чтобы воспользоваться преимуществами стандартных веб-технологий, но для app тесно общаться с различными функциями устройства уровень, вам нужно добавить плагины, которые обеспечивают доступ к основные API Cordova.

*Плагин* -это немного дополнения кода, который предоставляет интерфейс для родной компонентов. Вы можете создать свой собственный плагин интерфейс, например, при разработке приложения гибрид, который смешивает Cordova WebView с собственными компонентами. (См. Встраивание WebViews и плагин развития руководство для деталей.) Чаще всего можно добавить плагин, чтобы включить один из Кордова в основных функций устройства уровня подробно описаны в справочнике по API. Список этих плагинов, включая дополнительные плагины, сообщества, можно найти на [plugins.cordova.io][4]. CLI можно использовать для поиска плагинов из этого реестра. Например, поиск для `bar` и `code` производит один результат, соответствующий оба термина как подстроки без учета регистра:

 [4]: http://plugins.cordova.io/

        $ cordova plugin search bar code
    
        com.phonegap.plugins.barcodescanner - Scans Barcodes
    

Поиск только `bar` урожайность и дополнительный результат:

        org.apache.cordova.statusbar - Cordova StatusBar Plugin
    

`cordova plugin add`Команды необходимо указать хранилище для код плагина. Пожалуйста, обратите внимание, что когда вы следовать веб Dev проекта рабочего процесса и использовать CLI, CLI будет заботиться о добавлении плагин код в соответствующее место для каждой платформы. (Если вы после родной Dev рабочего проекта, вам придется добавить плагины, с помощью Plugman (руководство ссылку здесь), несколько раз для каждой платформы).

Ниже приведены примеры использования командной строки для добавления функций в приложение:

*   Информация основные устройства (устройства API):
    
        $ cordova plugin add org.apache.cordova.device
        

*   Сетевое подключение и батарея события:
    
        $ cordova plugin add org.apache.cordova.network-information
        $ cordova plugin add org.apache.cordova.battery-status
        

*   Акселерометр, компас и географического расположения:
    
        $ cordova plugin add org.apache.cordova.device-motion
        $ cordova plugin add org.apache.cordova.device-orientation
        $ cordova plugin add org.apache.cordova.geolocation
        

*   Камера, воспроизведение мультимедиа и захват:
    
        $ cordova plugin add org.apache.cordova.camera
        $ cordova plugin add org.apache.cordova.media-capture
        $ cordova plugin add org.apache.cordova.media
        

*   Доступ к файлам на устройстве или сети (файл API):
    
        $ cordova plugin add org.apache.cordova.file
        $ cordova plugin add org.apache.cordova.file-transfer
        

*   Уведомление через диалоговое окно или вибрации:
    
        $ cordova plugin add org.apache.cordova.dialogs
        $ cordova plugin add org.apache.cordova.vibration
        

*   Контакты:
    
        $ cordova plugin add org.apache.cordova.contacts
        

*   Глобализация:
    
        $ cordova plugin add org.apache.cordova.globalization
        

*   Экран-заставка:
    
        $ cordova plugin add org.apache.cordova.splashscreen
        

*   Открывать новые окна браузера (InAppBrowser):
    
        $ cordova plugin add org.apache.cordova.inappbrowser
        

*   Отладка консоли:
    
        $ cordova plugin add org.apache.cordova.console
        

Использование `plugin ls` (или `plugin list` , или `plugin` сама по себе) в настоящее время Просмотр установленных плагинов. Каждый отображает по его идентификатору:

        $ cordova plugin ls    # or 'plugin list'
        [ 'org.apache.cordova.console' ]
    

Чтобы удалить плагин, относятся к нему с тем же идентификатором, который появляется в списке. Например вот как бы удалить поддержку для консоли отладки версии:

        $ cordova plugin rm org.apache.cordova.console
        $ cordova plugin remove org.apache.cordova.console    # same
    

Можно пакет удалить или добавить плагины, указав более одного аргумента, для каждой команды:

        $ cordova plugin add org.apache.cordova.console org.apache.cordova.device
    

## Расширенный модуль параметры

При добавлении плагин, несколько вариантов позволяют указать где взять плагин. Приведенные выше примеры использования известного `registry.cordova.io` реестра и плагин определяется `id` :

        $ cordova plugin add org.apache.cordova.console
    

`id`Также могут включать номер версии плагина, добавленным после `@` характер. `latest`Версия — это псевдоним для самой последней версии. Например:

        $ cordova plugin add org.apache.cordova.console@latest
        $ cordova plugin add org.apache.cordova.console@0.2.1
    

Если плагин не зарегистрированы на `registry.cordova.io` , но расположен в другой репозиторий git, можно задать альтернативный URL-адрес:

        $ cordova plugin add https://github.com/apache/cordova-plugin-console.git
    

Приведенный выше пример git выбирает плагин с конца ветки master, но git ссылка на альтернативный например тег или ветви могут быть добавлены после `#` характер:

        $ cordova plugin add https://github.com/apache/cordova-plugin-console.git#r0.2.0
    

Если плагин (и его `plugin.xml` файл) находится в подкаталоге в git репо, вы можете определить его с `:` характер. Обратите внимание, что `#` персонаж по-прежнему необходимо:

        $ cordova plugin add https://github.com/someone/aplugin.git#:/my/sub/dir
    

Вы также можете объединить git-ref и подкаталога:

        $ cordova plugin add https://github.com/someone/aplugin.git#r0.0.1:/my/sub/dir
    

Кроме того, укажите локальный путь к папке плагина, который содержит `plugin.xml` файл:

        $ cordova plugin add ../my_plugin_dir
    

## Использование *слияния* для настройки каждой платформы

Хотя Cordova позволяет легко развертывать приложение на разных платформах, иногда необходимо добавить настройки. В этом случае, вы не хотите изменить исходные файлы в различных `www` каталогов в пределах верхнего уровня `platforms` каталог, потому что они регулярно вы заменили с верхнего уровня `www` кросс платформенной исходного каталога.

Вместо этого верхнего уровня `merges` Каталог предлагает место для указания активов для развертывания на определенных платформах. Каждый подкаталог платформа специфического в пределах `merges` отражает структуру каталогов `www` дерево исходных текстов, позволяет переопределить или добавить файлы, при необходимости. Например, вот как вы, возможно, использует `merges` чтобы увеличить размер шрифта по умолчанию для устройств Android и Amazon Fire ОС:

*   Редактировать `www/index.html` файл, добавив ссылку на дополнительные CSS-файл, `overrides.css` в этом случае:
    
        <link rel="stylesheet" type="text/css" href="css/overrides.css" />
        

*   При необходимости создать пустой `www/css/overrides.css` файл, который будет применяться для всех построений-андроида, предотвращая недостающий файл ошибка.

*   Создание `css` подкаталог внутри `merges/android` , затем добавить соответствующий `overrides.css` файл. Укажите CSS, который переопределяет размер шрифта 12 пунктов по умолчанию, указанный в `www/css/index.css` , например:
    
        body { font-size:14px; }
        

При повторном построении проекта, Android версия имеет размер пользовательского шрифта, в то время как другие остаются неизменными.

Вы можете также использовать `merges` для добавления файлов нет в оригинале `www` каталог. Например, приложение может включать *обратно кнопку* рисунок в интерфейс iOS, хранятся в `merges/ios/img/back_button.png` , в то время как Android версии вместо может захватить `backbutton` события из соответствующей аппаратной кнопки.

## Команды помощи

Cordova имеет несколько глобальных команд, которые могут помочь вам, если вы застряли или возникли проблемы. `help`Команда отображает все доступные команды Кордова и их синтаксис:

    $ cordova help
    $ cordova        # same
    

`info`Команда создает список потенциально полезных деталей, например, установленных платформ и плагины, SDK версии для каждой платформы и версии CLI и `node.js` :

    $ cordova info
    

Он представляет информацию на экран и перенаправляет выходные данные в локальной `info.txt` файла.

**Примечание**: в настоящее время, доступны только сведения о платформ iOS и Android.

## Обновление вашего проекта и Кордова

После установки `cordova` утилиты, вы можете всегда обновить его до последней версии, выполнив следующую команду:

        $ sudo npm update -g cordova
    

Используйте этот синтаксис для установки определенной версии:

        $ sudo npm install -g cordova@3.1.0-0.2.0
    

Запуск `cordova -v` чтобы посмотреть, какая версия в настоящее время работает. Запуск `npm
info` команда больше список, который включает в себя текущую версию и другие доступные версии номера:

        $ npm info cordova
    

Кордова 3.0 является первая версия для поддержки интерфейса командной строки, описанные в этом разделе. Если вы обновляете с версии 3.0, необходимо создать новый проект, как описано выше, а затем скопируйте старые приложения верхнего уровня `www` каталог. Там, где это применимо, далее сведения об обновлении до 3.0 доступны в платформе гидов. После обновления до `cordova` интерфейс командной строки и использование `npm update` в курсе, более длительных процедур, описанные там больше не актуальны.

Кордова 3.0 + могут по-прежнему требуют различных изменений структуры каталогов уровня проекта и другие зависимости. После запуска `npm` команда выше для обновления Cordova, сама, вам может понадобиться обеспечить вашего проекта ресурсы соответствовали требованиям последней версии. Выполните команды ниже для каждой платформы, вы создаете:

        $ cordova platform update android
        $ cordova platform update ios
        ...etc.
